package descartes.kieker4dql.dqlconnector.structures;

import java.io.IOException;
import java.io.InputStream;
import java.util.Map;
import java.util.Properties;

import kieker.common.logging.Log;
import kieker.common.logging.LogFactory;

public class Configuration extends Properties{


	private static final long serialVersionUID = 3566582505382356485L;
	private static final Log log = LogFactory.getLog(Configuration.class);


	public Configuration() {
	}


	public Configuration(String key, String sign) {
		super.put(key, sign);
	}


	public final void setPropertyArray(String key, Object[] sign){
		super.setProperty(key, toPropertyString(sign));
	}

	public static final String toPropertyString(final Object[] sign) {
		final StringBuilder sb = new StringBuilder();
		for (int i = 0; i < sign.length; i++) {
			sb.append(sign[i].toString());
			if (i < (sign.length - 1)) {
				sb.append('|');
			}
		}
		return sb.toString();
	}

	public static String generateID(Class<?> c){
		return c.getSimpleName() + "_CONFIG";
	}

	public final String getStringProperty(final String key) {
		final String sign = super.getProperty(key.trim());
		if (sign == null) {
			return "";
		}
		return sign.trim();
	}

	public final Boolean getBooleanProperty(final String key) {
		final String sign = super.getProperty(key.trim());
		Boolean out;
		try {
			if (sign != null) {
				out = Boolean.parseBoolean(sign);
				return out;
			}
		} catch (Exception e) {
			log.warn("String \"" + key + "\" does not refer a Boolean property");
		}
		return null;
	}

	public final Long getLongProperty(final String key) {
		final String sign = super.getProperty(key.trim());
		Long out;
		try {
			if (sign != null) {
				out = Long.parseLong(sign);
				return out;
			}
		} catch (Exception e) {
			log.warn("String \"" + key + "\" does not refer a Long property");
		}
		return null;
	}

	public final Double getDoubleProperty(final String key) {
		final String sign = super.getProperty(key.trim());
		Double out;
		try {
			if (sign != null) {
				out = Double.parseDouble(sign);
				return out;
			}
		} catch (Exception e) {
			log.warn("String \"" + key + "\" does not refer a Double property");
		}
		return null;
	}

	public final Integer getIntegerProperty(final String key) {
		final String sign = super.getProperty(key.trim());
		Integer out;
		try {
			if (sign != null) {
				out = Integer.parseInt(sign);
				return out;
			}
		} catch (Exception e) {
			log.warn("String \"" + key + "\" does not refer a Integer property");
		}
		return null;
	}


	public final String[] getPropertyArray(final String key) {
		super.getProperty(key.trim());
		String[] out = super.getProperty(key).split("&");
		for (String str : out) {
			if (!(str.length()==0 || str == null)) {
				str = str.trim();
			}
		}
		return out.clone();
	}

	@Override
	public synchronized void load(InputStream inStream) throws IOException {

		super.load(inStream);
	}
	
	
	public synchronized String toString() {
		return super.toString();
	}

	
	@Override
	@Deprecated
	public void putAll(Map<? extends Object,? extends Object> m){
		super.putAll(m);

	}

	@Override
	@Deprecated
	public Object put(Object key, Object sign){
		return super.put(key, sign);

	}

	@Override
	@Deprecated
	public Object get(Object key){
		return super.get(key);

	}

	@Override
	@Deprecated
	public synchronized Object getOrDefault(Object key, Object defaultValue) {
		return defaultValue;
	}

	@Override
	@Deprecated
	public Object putIfAbsent(Object key, Object sign){
		return super.putIfAbsent(key, sign);

	}


}
